"""Package watermark.py

A convinient python library to apply watermarks to images, gifs and videos.

MIT License

Copyright (c) 2021 Aahnik Daw

https://github.com/aahnik/watermark.py
"""

from importlib.metadata import version

__version__ = version(__package__)
